PEP: 210 Title: Decoupling the Interpreter Loop Version: $Revision$
Last-Modified: $Date$ Author: davida\@activestate.com (David Ascher)
Status: Rejected Type: Standards Track Content-Type: text/x-rst Created:
15-Jul-2000 Python-Version: 2.1 Post-History:

.. Local Variables: mode: indented-text indent-tabs-mode: nil End:
